import { HttpClient, MaybeContext, BuildRESTFunction } from '@wix/sdk-types';
import { ChannelWithLiterals, NotifyOptions } from './index.typings.mjs';
export { Channel, DashboardPages, Empty, NotifyOptionsActionTargetOneOf, NotifyOptionsRecipientsFilterOneOf, PublicNotifyRequest, PublicNotifyRequestActionTargetOneOf, PublicNotifyRequestRecipientsFilterOneOf, Public_notification, Role, ToContacts, ToSiteContributors, ToTopicsSubscribers } from './index.typings.mjs';

declare function notify$1(httpClient: HttpClient): NotifySignature;
interface NotifySignature {
    /**
     * Sends a notification.
     *
     *
     * The `notify()` function sends a [notification](https://support.wix.com/en/article/about-your-dashboard-notifications) to the specified recipients on the specified channels.
     *
     * List the the channels for the notification in the `channels` parameter .
     *
     * List the recipients for the notification in the `toContacts`, `toSiteContributors`, and `toTopicsSubscribers` parameters.
     * @param - Notification options.
     * @param - Body of the notification. This contains the main content of the notification.
     * @param - Channel through which users receive the notification.
     * - `"Mobile"`: Sends the notification to the Wix App.
     * - `"Dashboard"`: Sends the notification to the collaborator's Wix Dashboard.
     * - `"Browser"`: Sends the notification to the collaborator's browser.
     * @returns Fulfilled when the send notification request is received.
     */
    (body: string, channels: ChannelWithLiterals[], options?: NotifyOptions): Promise<void>;
}

declare const notify: MaybeContext<BuildRESTFunction<typeof notify$1> & typeof notify$1>;

export { NotifyOptions, notify };
