// src/ping-notifications-v1-public-notification-notifications.universal.ts
import { transformError as sdkTransformError } from "@wix/sdk-runtime/transform-error";
import { renameKeysFromSDKRequestToRESTRequest } from "@wix/sdk-runtime/rename-all-nested-keys";

// src/ping-notifications-v1-public-notification-notifications.http.ts
import { resolveUrl } from "@wix/sdk-runtime/rest-modules";
function resolveComWixpressPingHubApiPublicNotificationsServiceUrl(opts) {
  const domainToMappings = {
    "api._api_base_domain_": [
      {
        srcPath: "/notifications-hub-server",
        destPath: ""
      }
    ],
    "www._base_domain_": [
      {
        srcPath: "/_api/ping/hub",
        destPath: ""
      },
      {
        srcPath: "/_api/ping/notifications",
        destPath: ""
      }
    ],
    "manage._base_domain_": [
      {
        srcPath: "/_api/ping/hub",
        destPath: ""
      },
      {
        srcPath: "/_api/ping/notifications",
        destPath: ""
      }
    ],
    "www.wixapis.com": [
      {
        srcPath: "/notifications/v3/notify",
        destPath: "/v3/notify"
      }
    ]
  };
  return resolveUrl(Object.assign(opts, { domainToMappings }));
}
var PACKAGE_NAME = "@wix/auto_sdk_notifications_notifications";
function notify(payload) {
  function __notify({ host }) {
    const metadata = {
      entityFqdn: "wix.ping.notifications.v1.public_notification",
      method: "POST",
      methodFqn: "com.wixpress.ping.hub.api.PublicNotificationsService.Notify",
      packageName: PACKAGE_NAME,
      url: resolveComWixpressPingHubApiPublicNotificationsServiceUrl({
        protoPath: "/api/v1/notify",
        data: payload,
        host
      }),
      data: payload
    };
    return metadata;
  }
  return __notify;
}

// src/ping-notifications-v1-public-notification-notifications.universal.ts
var Role = /* @__PURE__ */ ((Role2) => {
  Role2["All_Contributors"] = "All_Contributors";
  Role2["Owner"] = "Owner";
  return Role2;
})(Role || {});
var Channel = /* @__PURE__ */ ((Channel2) => {
  Channel2["Undefined"] = "Undefined";
  Channel2["Dashboard"] = "Dashboard";
  Channel2["Mobile"] = "Mobile";
  Channel2["Browser"] = "Browser";
  return Channel2;
})(Channel || {});
var DashboardPages = /* @__PURE__ */ ((DashboardPages2) => {
  DashboardPages2["Undefined_Page"] = "Undefined_Page";
  DashboardPages2["Home"] = "Home";
  return DashboardPages2;
})(DashboardPages || {});
async function notify2(body, channels, options) {
  const { httpClient, sideEffects } = arguments[3];
  const payload = renameKeysFromSDKRequestToRESTRequest({
    body,
    channels,
    toSiteContributors: options?.toSiteContributors,
    toContacts: options?.toContacts,
    title: options?.title,
    action: options?.action,
    targetUrl: options?.targetUrl,
    targetDashboardPage: options?.targetDashboardPage
  });
  const reqOpts = notify(payload);
  sideEffects?.onSiteCall?.();
  try {
    const result = await httpClient.request(reqOpts);
    sideEffects?.onSuccess?.(result);
  } catch (err) {
    const transformedError = sdkTransformError(
      err,
      {
        spreadPathsToArguments: {},
        explicitPathsToArguments: {
          body: "$[0]",
          channels: "$[1]",
          toSiteContributors: "$[2].toSiteContributors",
          toContacts: "$[2].toContacts",
          title: "$[2].title",
          action: "$[2].action",
          targetUrl: "$[2].targetUrl",
          targetDashboardPage: "$[2].targetDashboardPage"
        },
        singleArgumentUnchanged: false
      },
      ["body", "channels", "options"]
    );
    sideEffects?.onError?.(err);
    throw transformedError;
  }
}
export {
  Channel,
  DashboardPages,
  Role,
  notify2 as notify
};
//# sourceMappingURL=index.typings.mjs.map