import { PublicNotifyRequest as PublicNotifyRequest$1, Empty as Empty$1 } from './index.typings.mjs';

interface PublicNotifyRequest extends PublicNotifyRequestRecipientsFilterOneOf, PublicNotifyRequestActionTargetOneOf {
    /** Send to [site contributors]((https://support.wix.com/en/article/roles-permissions-overview)). This includes site administrators, website managers, and back office managers. */
    toSiteContributors?: ToSiteContributors;
    /** Send to [site contacts](https://support.wix.com/en/article/about-your-contact-list). */
    toContacts?: ToContacts;
    /** External URL to open when the notification action is clicked. */
    targetUrl?: string | null;
    /** Dashboard page to open when the notification action is clicked. */
    targetDashboardPage?: DashboardPagesWithLiterals;
    /** Title of the notification. */
    title?: string | null;
    /** Body of the notification. This contains the main content of the notification. */
    body?: string | null;
    /** Title of the notification action. Clicking the action refers the user to a target URL or a dashboard page. */
    action?: string | null;
    /**
     * Channel through which users receive the notification.
     * @maxSize 20
     */
    channels?: ChannelWithLiterals[];
}
/** @oneof */
interface PublicNotifyRequestRecipientsFilterOneOf {
    /** Send to [site contributors]((https://support.wix.com/en/article/roles-permissions-overview)). This includes site administrators, website managers, and back office managers. */
    toSiteContributors?: ToSiteContributors;
    /** Send to [site contacts](https://support.wix.com/en/article/about-your-contact-list). */
    toContacts?: ToContacts;
}
/** @oneof */
interface PublicNotifyRequestActionTargetOneOf {
    /** External URL to open when the notification action is clicked. */
    targetUrl?: string | null;
    /** Dashboard page to open when the notification action is clicked. */
    targetDashboardPage?: DashboardPagesWithLiterals;
}
interface ToSiteContributors {
    /** Role assigned to site contributors. Only contributors with the specified roles receive the notification. */
    withRole?: RoleWithLiterals;
}
declare enum Role {
    /** All site contributors. */
    All_Contributors = "All_Contributors",
    /** Site owner only. */
    Owner = "Owner"
}
/** @enumType */
type RoleWithLiterals = Role | 'All_Contributors' | 'Owner';
interface ToContacts {
    /**
     * Contacts that receive the notification.
     * @format GUID
     * @maxSize 1000
     */
    contactIds?: string[];
}
declare enum Channel {
    /** No default channel. */
    Undefined = "Undefined",
    /** Site dashboard. */
    Dashboard = "Dashboard",
    /** [Wix Owner](https://www.wix.com/mobile/wix-app) mobile app. */
    Mobile = "Mobile",
    /** Active browser. Supported on Chrome and Safari only. */
    Browser = "Browser"
}
/** @enumType */
type ChannelWithLiterals = Channel | 'Undefined' | 'Dashboard' | 'Mobile' | 'Browser';
declare enum DashboardPages {
    Undefined_Page = "Undefined_Page",
    /** Site dashboard home. */
    Home = "Home"
}
/** @enumType */
type DashboardPagesWithLiterals = DashboardPages | 'Undefined_Page' | 'Home';
interface Empty {
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function notify(): __PublicMethodMetaInfo<'POST', {}, PublicNotifyRequest$1, PublicNotifyRequest, Empty$1, Empty>;

export { type __PublicMethodMetaInfo, notify };
